@@ -7,11 +7,11 @@ from pyelasticsearch.exceptions import (Timeout, ConnectionError,
                                         ElasticHttpNotFoundError,
                                         IndexAlreadyExistsError)
 
-__author__ = 'Robert Eanes'
+__author__ = 'Erik Rose'
 __all__ = ['ElasticSearch', 'ElasticHttpError', 'InvalidJsonResponseError',
            'Timeout', 'ConnectionError', 'ElasticHttpNotFoundError',
            'IndexAlreadyExistsError']
-__version__ = '0.4.1'
+__version__ = '0.7'
 __version_info__ = tuple(__version__.split('.'))
 
 get_version = lambda: __version_info__
